@@ -343,7 +343,7 @@ fn print_status(
     ctx,
     r#"Status:
   model:             {model}
-  serial number:     0x{id}
+  serial number:     {id}
   firmware version:  {fwv}
   user retry count:  {urc}
   admin retry count: {arc}"#,
@@ -356,7 +356,7 @@ fn print_status(
 
   if let nitrokey::DeviceWrapper::Storage(device) = device {
     let status = device
-      .get_status()
+      .get_storage_status()
       .map_err(|err| get_error("Getting Storage status failed", err))?;
 
     print_storage_status(ctx, &status)
@@ -376,6 +376,44 @@ pub fn status(ctx: &mut args::ExecCtx<'_>) -> Result<()> {
   })
 }
 
+/// List the attached Nitrokey devices.
+pub fn list(ctx: &mut args::ExecCtx<'_>, no_connect: bool) -> Result<()> {
+  set_log_level(ctx);
+
+  let device_infos = nitrokey::list_devices()?;
+  if device_infos.is_empty() {
+    println!(ctx, "No Nitrokey device connected")?;
+  } else {
+    println!(ctx, "device path\tmodel\tserial number")?;
+    let mut manager = nitrokey::take()?;
+
+    for device_info in device_infos {
+      let model = device_info
+        .model
+        .map(|m| m.to_string())
+        .unwrap_or_else(|| "unknown".into());
+      let serial_number = match device_info.serial_number {
+        Some(serial_number) => serial_number.to_string(),
+        None => {
+          // Storage devices do not have the serial number present in
+          // the device information. We have to connect to them to
+          // retrieve the information.
+          if no_connect {
+            "N/A".to_string()
+          } else {
+            let device = manager.connect_path(device_info.path.clone())?;
+            device.get_serial_number()?.to_string()
+          }
+        }
+      };
+
+      println!(ctx, "{}\t{}\t{}", device_info.path, model, serial_number)?;
+    }
+  }
+
+  Ok(())
+}
+
 /// Perform a factory reset.
 pub fn reset(ctx: &mut args::ExecCtx<'_>) -> Result<()> {
   with_device(ctx, |ctx, mut device| {
