@@ -34,7 +34,6 @@
   overflowing_literals,
   path_statements,
   patterns_in_fns_without_body,
-  plugin_as_library,
   private_in_public,
   proc_macro_derive_resolution_fallback,
   renamed_and_removed_lints,
@@ -86,7 +85,6 @@ use crate::error::Error;
 
 type Result<T> = result::Result<T, Error>;
 
-const NITROCLI: &str = "nitrocli";
 const NITROCLI_ADMIN_PIN: &str = "NITROCLI_ADMIN_PIN";
 const NITROCLI_USER_PIN: &str = "NITROCLI_USER_PIN";
 const NITROCLI_NEW_ADMIN_PIN: &str = "NITROCLI_NEW_ADMIN_PIN";
@@ -121,18 +119,10 @@ pub(crate) struct RunCtx<'io> {
 fn run<'ctx, 'io: 'ctx>(ctx: &'ctx mut RunCtx<'io>, args: Vec<String>) -> i32 {
   match args::handle_arguments(ctx, args) {
     Ok(()) => 0,
-    Err(err) => match err {
-      Error::ArgparseError(err) => match err {
-        // argparse printed the help message
-        0 => 0,
-        // argparse printed an error message
-        _ => 1,
-      },
-      _ => {
-        let _ = eprintln!(ctx, "{}", err);
-        1
-      }
-    },
+    Err(err) => {
+      let _ = eprintln!(ctx, "{}", err);
+      1
+    }
   }
 }
 
