@@ -25,6 +25,7 @@ use nitrokey_test::test as test_device;
 mod config;
 mod encrypted;
 mod hidden;
+mod list;
 mod lock;
 mod otp;
 mod pin;
@@ -50,6 +51,13 @@ where
 {
   fn unwrap_str_err(self) -> String {
     match self.unwrap_err() {
+      crate::Error::ClapError(err) => {
+        if err.use_stderr() {
+          err.message
+        } else {
+          String::new()
+        }
+      }
       crate::Error::Error(err) => err,
       err => panic!("Unexpected error variant found: {:?}", err),
     }
